<?xml version="1.0"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:import href="Animal"/>
<xsl:output method="html" indent="no" encoding="UTF-8"/>


<xsl:template match="/character">
	<b><xsl:value-of select="name"/></b>:
	<xsl:text> </xsl:text>

	<xsl:choose>
	<xsl:when test="gender != ''">
		<xsl:value-of select="gender"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="race"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="classes/string"/>;
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="class"/>;
	</xsl:otherwise>
	</xsl:choose>
	<xsl:text> </xsl:text>

	<xsl:if test="challenge-rating != 0">
		CR <xsl:value-of select="challenge-rating"/>;
	</xsl:if>

	<xsl:value-of select="size/category"/>
	<xsl:text> </xsl:text>
	<xsl:value-of select="size/type"/>
	<xsl:text> </xsl:text>
	<xsl:value-of select="size/subtype"/>;
	<xsl:text> </xsl:text>

	HD
	<xsl:text> </xsl:text>
	<xsl:for-each select="hit-dice/hit-die">
		<xsl:value-of select="die"/><xsl:value-of select="bonus"/>
		<xsl:text> </xsl:text>
		(<xsl:value-of select="class"/>)
		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	hp <xsl:value-of select="hit-points"/>;
	<xsl:text> </xsl:text>

	<xsl:variable name="init" select="sum(initiative/modifiers/modifier[@name != 'misc']/@value)"/>
	<xsl:text>Init </xsl:text>
	<xsl:if test="$init >= 0">
		+
	</xsl:if>
	<xsl:value-of select="$init"/>;
	<xsl:text> </xsl:text>

	<xsl:text>Spd </xsl:text>
	<xsl:for-each select="speeds/speed">
		<xsl:if test="position() &gt; 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:choose>
		<xsl:when test="name = 'Base'">
			<xsl:value-of select="value"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="name"/>
			<xsl:text> </xsl:text>
			<xsl:value-of select="value"/>
		</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:if>
	</xsl:for-each>

	AC <xsl:value-of select="sum(armor-class/modifiers/modifier[@name != 'misc']/@value)"/>;
	<xsl:text> </xsl:text>

	<xsl:variable name="melee" select="sum(attacks/melee/modifiers/modifier[@name != 'misc']/@value)"/>
	<xsl:text>Atk </xsl:text>
	<xsl:if test="$melee >= 0">
		+
	</xsl:if>
	<xsl:value-of select="$melee"/>
	<xsl:text> base melee, </xsl:text>

	<xsl:variable name="ranged" select="sum(attacks/ranged/modifiers/modifier[@name != 'misc']/@value)"/>
	<xsl:if test="$ranged >= 0">
		+
	</xsl:if>
	<xsl:value-of select="$ranged"/>
	<xsl:text> base ranged; </xsl:text>

	<xsl:for-each select="equiped-items/weapons">
		<xsl:for-each select="weapon">
			<xsl:value-of select="bonus"/>
			<xsl:choose>
			<xsl:when test="position() = last()">
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>/</xsl:text>
			</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>

		<xsl:text> </xsl:text>(
		<xsl:for-each select="weapon">
			<xsl:value-of select="damage"/>, <xsl:value-of select="name"/>
			<xsl:choose>
			<xsl:when test="position() = last()">
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>; </xsl:text>
			</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		);<xsl:text> </xsl:text>
	</xsl:for-each>


	<xsl:for-each select="features/special-attacks/special-attack">
		<xsl:if test="position() = 1">
			<xsl:text>SA: </xsl:text>
		</xsl:if>
		<xsl:value-of select="."/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:for-each select="features/special-qualities/special-quality">
		<xsl:if test="position() = 1">
			<xsl:text>SQ: </xsl:text>
		</xsl:if>
		<xsl:value-of select="."/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:for-each select="features/class-features">
		<xsl:if test="position() = 1">
			<xsl:text>Class Features: </xsl:text>
		</xsl:if>
			<xsl:for-each select="class-feature">
		<xsl:value-of select="name"/>: 
			<xsl:for-each select="feature">
			<xsl:value-of select="."/>
		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>
	</xsl:for-each>
	</xsl:for-each>

	<xsl:for-each select="features/race-features/race-feature">
		<xsl:if test="position() = 1">
			<xsl:text>Racial Features: </xsl:text>
		</xsl:if>
		<xsl:value-of select="."/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:if test="spell-resistance != ''">
		SR <xsl:value-of select="spell-resistance"/>;
		<xsl:text> </xsl:text>
	</xsl:if>

	AL <xsl:value-of select="alignment/abbr"/>;
	<xsl:text> </xsl:text>

	<xsl:text>SV </xsl:text>
	<xsl:for-each select="saving-throws/saving-throw">
		<xsl:value-of select="abbr"/>
		<xsl:text> </xsl:text>

		<xsl:variable name="save" select="sum(modifiers/modifier[@name != 'misc']/@value)"/>
		<xsl:if test="$save >= 0">
			+
		</xsl:if>
		<xsl:value-of select="$save"/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:for-each select="abilities/ability">
		<xsl:value-of select="abbr"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="base"/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>.</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:if test="items/item != ''">
		<br/><br/><i>Possessions:</i>
		<xsl:if test="items/item[type = 'Weapon'] != ''">
			<br/><xsl:text>Weapons: </xsl:text>
			<xsl:for-each select="items/item[type = 'Weapon']">
				<xsl:value-of select="name"/>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="items/item[type = 'Armor'] != ''">
			<br/><xsl:text>Armor: </xsl:text>
			<xsl:for-each select="items/item[type = 'Armor']">
				<xsl:value-of select="name"/>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="items/item[type = 'Shield'] != ''">
			<br/><xsl:text>Shields: </xsl:text>
			<xsl:for-each select="items/item[type = 'Shield']">
				<xsl:value-of select="name"/>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="items/item[type = 'Goods' or type = 'Art' or type = 'Gem'] != ''">
			<br/><xsl:text>Goods: </xsl:text>
			<xsl:for-each select="items/item[type = 'Goods' or type = 'Art' or type = 'Gem']">
				<xsl:value-of select="name"/>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="items/item[type = 'Potion' or type = 'Ring' or type = 'Rod' or type = 'Scroll' or type = 'Staff' or type = 'Wand' or type = 'Wondrous'] != ''">
			<br/><xsl:text>Magic: </xsl:text>
			<xsl:for-each select="items/item[type = 'Potion' or type = 'Ring' or type = 'Rod' or type = 'Scroll' or type = 'Staff' or type = 'Wand' or type = 'Wondrous']">
				<xsl:value-of select="type"/>:
				<xsl:text> </xsl:text>
				<xsl:value-of select="name"/>
				<xsl:choose>
				<xsl:when test="position() = last()">
					<xsl:text>.</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>; </xsl:text>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
	</xsl:if>

	<xsl:for-each select="skills/skill[modifiers/modifier[@name = 'rank' or @name = 'race' or @name = 'magic' or @name = 'feat' or @name = 'other']/@value &gt; 0]">
		<xsl:sort select="string(.)"/>
		<xsl:if test="position() = 1">
			<br/><br/><i>Skills: </i>
		</xsl:if>
		<xsl:value-of select="name"/><xsl:text> </xsl:text>
		<xsl:if test="sum(modifiers/modifier[@name != 'misc']/@value) >= 0">
			 +
		</xsl:if>
		<xsl:value-of select="sum(modifiers/modifier[@name != 'misc']/@value)"/>
		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>. </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:for-each select="features/feats/feat">
		<xsl:sort select="string(.)"/>
		<xsl:if test="position() = 1">
			<br/><i>Feats: </i>
		</xsl:if>
		<xsl:value-of select="name"/>
		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>.</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

				<xsl:for-each select="deity/domain">
					<xsl:if test="position() = 1">
					<br/><i>Domains:</i> <xsl:text> </xsl:text>

					</xsl:if>
					<xsl:if test="position() = 2">
						<xsl:text>, </xsl:text>
					</xsl:if>
					<xsl:value-of select="name"/>
					<xsl:if test="position() = last()">
					<xsl:text>. </xsl:text> <i>Deity:</i> 
						<xsl:text> </xsl:text>
					</xsl:if>
				</xsl:for-each>
					<xsl:value-of select="deity/name"/>

				<xsl:for-each select="deity/domain">
					<xsl:if test="position() = 1">
					<br/><i>Domain Powers:</i> <xsl:text> </xsl:text>

					</xsl:if>
					<xsl:if test="position() = 2">
						<xsl:text>; </xsl:text>
					</xsl:if>
					<xsl:value-of select="special-power"/>
					<xsl:if test="position() = last()">
					<xsl:text>. </xsl:text>
					</xsl:if>
				</xsl:for-each>

	<xsl:for-each select="spells-known/class">
		<xsl:if test="full-name != 'Cleric'">

		<br/><br/><i>Spells Known <xsl:value-of select="name"/>: </i>

		<xsl:if test="count(spell[level = '0']) > 0">
			<xsl:text>0 - </xsl:text>
			<xsl:for-each select="spell[level = '0']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '1']) > 0">
			<xsl:text>; 1st - </xsl:text>
			<xsl:for-each select="spell[level = '1']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '2']) > 0">
			<xsl:text>; 2nd - </xsl:text>
			<xsl:for-each select="spell[level = '2']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '3']) > 0">
			<xsl:text>; 3rd - </xsl:text>
			<xsl:for-each select="spell[level = '3']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '4']) > 0">
			<xsl:text>; 4th - </xsl:text>
			<xsl:for-each select="spell[level = '4']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '5']) > 0">
			<xsl:text>; 5th - </xsl:text>
			<xsl:for-each select="spell[level = '5']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '6']) > 0">
			<xsl:text>; 6th - </xsl:text>
			<xsl:for-each select="spell[level = '6']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '7']) > 0">
			<xsl:text>; 7th - </xsl:text>
			<xsl:for-each select="spell[level = '7']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '8']) > 0">
			<xsl:text>; 8th - </xsl:text>
			<xsl:for-each select="spell[level = '8']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '9']) > 0">
			<xsl:text>; 9th - </xsl:text>
			<xsl:for-each select="spell[level = '9']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
		<xsl:text>.</xsl:text>

		</xsl:if>
	</xsl:for-each>

	<xsl:for-each select="spells-prepared/class">
		<br/><br/><i>Spells Prepared <xsl:value-of select="name"/>: </i>

		<xsl:if test="count(spell[level = '0']) > 0">
			<xsl:text>0 - </xsl:text>
			<xsl:for-each select="spell[level = '0']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '1']) > 0">
			<xsl:text>; 1st - </xsl:text>
			<xsl:for-each select="spell[level = '1']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '2']) > 0">
			<xsl:text>; 2nd - </xsl:text>
			<xsl:for-each select="spell[level = '2']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '3']) > 0">
			<xsl:text>; 3rd - </xsl:text>
			<xsl:for-each select="spell[level = '3']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '4']) > 0">
			<xsl:text>; 4th - </xsl:text>
			<xsl:for-each select="spell[level = '4']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '5']) > 5">
			<xsl:text>; 5th - </xsl:text>
			<xsl:for-each select="spell[level = '5']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '6']) > 0">
			<xsl:text>; 6th - </xsl:text>
			<xsl:for-each select="spell[level = '6']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '7']) > 0">
			<xsl:text>; 7th - </xsl:text>
			<xsl:for-each select="spell[level = '7']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '8']) > 0">
			<xsl:text>; 8th - </xsl:text>
			<xsl:for-each select="spell[level = '8']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

		<xsl:if test="count(spell[level = '9']) > 0">
			<xsl:text>; 9th - </xsl:text>
			<xsl:for-each select="spell[level = '9']">
				<xsl:sort select="string(.)"/>
				<i><xsl:value-of select="name"/><xsl:apply-templates select="count"/></i>
				<xsl:choose>
				<xsl:when test="position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>
		<xsl:text>.</xsl:text>
	</xsl:for-each>

	<br/><br/>
	<xsl:for-each select="animals/animal">
		<xsl:apply-templates select="."/><br/>
	</xsl:for-each>
	<br/>
</xsl:template>


<xsl:template match="count">
	<xsl:if test=". &gt; 1">
		<xsl:text> x</xsl:text><xsl:value-of select="."/>
	</xsl:if>
</xsl:template>

</xsl:stylesheet>










