<?xml version="1.0"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:import href="Animal.xsl"/>
<xsl:import href="Items.xsl"/>
<xsl:import href="Skills.xsl"/>
<xsl:import href="Feats.xsl"/>
<xsl:import href="Spells Known.xsl"/>
<xsl:import href="Spells Prepared.xsl"/>
<xsl:output method="html" indent="no" encoding="UTF-8"/>

<xsl:template match="character">
	<b>
	<xsl:value-of select="name"/>

	<xsl:choose>
	<xsl:when test="gender != ''">
		<xsl:text>, </xsl:text>
		<xsl:value-of select="gender"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="race"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="classes/string"/>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="class"/>
	</xsl:otherwise>
	</xsl:choose>

	<xsl:if test="number(number) &gt; 1">
		<xsl:text> </xsl:text>(<xsl:value-of select="./number"/>)
	</xsl:if>
	<xsl:text>:</xsl:text>
	</b>
	<xsl:text> </xsl:text>

	<xsl:if test="challenge-rating != 0">
		CR <xsl:value-of select="challenge-rating"/>;
	</xsl:if>

	<xsl:value-of select="size/category"/>
	<xsl:text> </xsl:text>
	<xsl:value-of select="size/type"/>
	<xsl:text> </xsl:text>
	<xsl:value-of select="size/subtype"/>;
	<xsl:text> </xsl:text>

	HD
	<xsl:text> </xsl:text>
	<xsl:for-each select="hit-dice/hit-die">
		<xsl:value-of select="die"/><xsl:value-of select="bonus"/>
		<xsl:text> </xsl:text>
		(<xsl:value-of select="class"/>)
		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	hp <xsl:value-of select="hit-points"/>;
	<xsl:text> </xsl:text>

	<xsl:variable name="init" select="sum(initiative/modifiers/modifier[@name != 'misc']/@value)"/>
	<xsl:text>Init </xsl:text>
	<xsl:if test="$init >= 0">
		+
	</xsl:if>
	<xsl:value-of select="$init"/>;
	<xsl:text> </xsl:text>

	<xsl:text>Spd </xsl:text>
	<xsl:for-each select="speeds/speed">
		<xsl:if test="position() &gt; 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:choose>
		<xsl:when test="name = 'Base'">
			<xsl:value-of select="value"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="name"/>
			<xsl:text> </xsl:text>
			<xsl:value-of select="value"/>
		</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:if>
	</xsl:for-each>

	AC <xsl:value-of select="sum(armor-class/modifiers/modifier[@name != 'misc']/@value)"/>;
	<xsl:text> </xsl:text>

	<xsl:variable name="melee" select="sum(attacks/melee/modifiers/modifier[@name != 'misc']/@value)"/>
	<xsl:text>Atk </xsl:text>
	<xsl:if test="$melee >= 0">
		+
	</xsl:if>
	<xsl:value-of select="$melee"/>
	<xsl:text> base melee, </xsl:text>

	<xsl:variable name="ranged" select="sum(attacks/ranged/modifiers/modifier[@name != 'misc']/@value)"/>
	<xsl:if test="$ranged >= 0">
		+
	</xsl:if>
	<xsl:value-of select="$ranged"/>
	<xsl:text> base ranged; </xsl:text>

	<xsl:for-each select="equiped-items/weapons">
		<xsl:for-each select="weapon">
			<xsl:value-of select="bonus"/>
			<xsl:choose>
			<xsl:when test="position() = last()">
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>/</xsl:text>
			</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>

		<xsl:text> </xsl:text>(
		<xsl:for-each select="weapon">
			<xsl:value-of select="damage"/>, <xsl:value-of select="name"/>
			<xsl:choose>
			<xsl:when test="position() = last()">
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>; </xsl:text>
			</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		);<xsl:text> </xsl:text>
	</xsl:for-each>


	<xsl:for-each select="features/special-attacks/special-attack">
		<xsl:if test="position() = 1">
			<xsl:text>SA: </xsl:text>
		</xsl:if>
		<xsl:value-of select="."/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:for-each select="features/special-qualities/special-quality">
		<xsl:if test="position() = 1">
			<xsl:text>SQ: </xsl:text>
		</xsl:if>
		<xsl:value-of select="."/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:for-each select="features/race-features/race-feature">
		<xsl:if test="position() = 1">
			<xsl:text>RF: </xsl:text>
		</xsl:if>
		<xsl:value-of select="."/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:if test="spell-resistance != ''">
		SR <xsl:value-of select="spell-resistance"/>;
		<xsl:text> </xsl:text>
	</xsl:if>

	AL <xsl:value-of select="alignment/abbr"/>;
	<xsl:text> </xsl:text>

	<xsl:text>SV </xsl:text>
	<xsl:for-each select="saving-throws/saving-throw">
		<xsl:value-of select="abbr"/>
		<xsl:text> </xsl:text>

		<xsl:variable name="save" select="sum(modifiers/modifier[@name != 'misc']/@value)"/>
		<xsl:if test="$save >= 0">
			+
		</xsl:if>
		<xsl:value-of select="$save"/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>; </xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:for-each select="abilities/ability">
		<xsl:value-of select="abbr"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="base"/>

		<xsl:choose>
		<xsl:when test="position() = last()">
			<xsl:text>.</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>, </xsl:text>
		</xsl:otherwise>
		</xsl:choose>
	</xsl:for-each>

	<xsl:apply-templates select="skills"/>
	<xsl:apply-templates select="features/feats"/>

	<xsl:apply-templates select="spells-known"/>
	<xsl:apply-templates select="spells-prepared"/>

	<xsl:if test="count(items/item) > 0">
		<br/><b>Possessions:</b><xsl:text> </xsl:text>
	</xsl:if>
	<xsl:apply-templates select="items"/>
	<br/>

	<xsl:for-each select="animals/animal">
		<xsl:apply-templates select="."/><br/>
	</xsl:for-each>

	<br/>
</xsl:template>

</xsl:stylesheet>










